@@ -1,6 +1,6 @@
 ;;;                 COPYRIGHT NOTICE
 ;;;  
-;;;  Copyright (C) 2007-2012 Mario Rodriguez Riotorto
+;;;  Copyright (C) 2007-2013 Mario Rodriguez Riotorto
 ;;;  
 ;;;  This program is free software; you can redistribute
 ;;;  it and/or modify it under the terms of the
@@ -15,14 +15,26 @@
 ;;;  GNU General Public License for more details at
 ;;;  http://www.gnu.org/copyleft/gpl.html
 
-;;; This file is the options handler of package draw
+;;; This is a maxima-gnuplot interface.
+
+;;; Visit
+;;; http://riotorto.users.sourceforge.net/gnuplot
+;;; for examples
+
+;;; Some portions of this package were written by 
+;;; Andrej Vodopivec and Joan Pau Beltran.
+;;; Some other people has also helped with bug reports,
+;;; comments, complains and feature requests.
+;;; Thanks to everybody!!
 
 ;;; For questions, suggestions, bugs and the like, feel free
 ;;; to contact me at
+
 ;;; mario @@@ edu DOT xunta DOT es
 
 
-($put '$grcommon 1 '$version)
+($put '$draw 2 '$version)
+
 
 ;; Possible draw renderers:
 ;;      gnuplot_pipes (default)
@@ -32,28 +44,24 @@
 
 (defvar $draw_use_pngcairo nil "If true, use pngcairo terminal when png is requested.")
 
-;; Stores actual graphics options
-(defvar *gr-options* (make-hash-table))
 
 ;; Stores user defaults
 (defvar *user-gr-default-options* nil)
-
-;; Stores user defined allocations of scenes
-(defvar *allocations* nil)
-
 (defun $set_draw_defaults (&rest opts)
    (setf *user-gr-default-options* opts)
    (cons '(mlist) opts))
-
-;; Sets user default values of graphics options
 (defun user-defaults ()
    (dolist (x *user-gr-default-options*)
       (if (equal ($op x) "=")
          (update-gr-option ($lhs x) ($rhs x))
          (merror "draw: item ~M is not recognized as an option assignment" x))))
 
+;; Stores user defined allocations of scenes
+(defvar *allocations* nil)
+
 
 ;; Sets default values of graphics options
+(defvar *gr-options* (make-hash-table))
 (defun ini-gr-options ()
   (setf
       ; global options to control general aspects of graphics
@@ -187,9 +195,6 @@
       (gethash '$tube_extremes *gr-options*) '((mlist simp) '$open '$open) ; or '$closed
   ) )
 
-
-
-
 ;; Returns option value
 (defun get-option (opt) (gethash opt *gr-options*))
 
@@ -197,6 +202,7 @@
 
 
 
+
 ;; update options color, fill_color, xaxis_color, yaxis_color,
 ;; $zaxis_color, and $background_color
 ;; -----------------------------------------------------------
@@ -330,6 +336,7 @@
 
 
 
+
 ;; update option terminal
 ;; ----------------------
 ;; *draw-terminal-number* is used when working with
@@ -338,9 +345,11 @@
 (defvar *draw-terminal-number* "")
 
 (defun update-terminal (val)
-  (let ((terms '($screen $png $pngcairo $jpg $gif $eps $eps_color $svg
+  (let ((terms '($screen $png $pngcairo $jpg $gif $eps $eps_color 
+                 $epslatex $epslatex_standalone $svg $x11
                  $dumb $dumb_file $pdf $pdfcairo $wxt $animated_gif
-                 $aquaterm $tiff $vrml $obj $pnm)))
+                 $multipage_pdfcairo $multipage_pdf $multipage_eps 
+                 $multipage_eps_color $aquaterm $tiff $vrml $obj $pnm)))
      (cond
        ((member val terms)
           (when (and (eq val '$png) $draw_use_pngcairo)
@@ -359,6 +368,7 @@
 
 
 
+
 ;; update option transform
 ;; -----------------------
 (defvar *draw-transform-dimensions* 0)
@@ -439,6 +449,7 @@
 
 
 
+
 ;; update option enhanced3d
 ;; ------------------------
 (defvar *draw-enhanced3d-type* 0)
@@ -552,8 +563,8 @@
        (let ((rv ($float (cadr val)))
              (rh ($float (caddr val))) )
          (unless
-           (and (numberp rv) (>= rv 0) (<= rv 180) )
-           (merror "draw: vertical rotation angle must be in [0, 180]"))
+           (and (numberp rv) (>= rv 0) (<= rv 360) )
+           (merror "draw: vertical rotation angle must be in [0, 360]"))
          (unless
            (and (numberp rh) (>= rh 0) (<= rh 360) )
            (merror "draw: horizontal rotation angle must be in [0, 360]"))
@@ -728,9 +739,6 @@
 
 
 
-
-
-
 (defun ini-local-option-variables ()
   (setf ; global variables
        *draw-transform-dimensions* 0
@@ -742,7 +750,6 @@
 
 
 
-
 ;; Sets default values to global options
 (defun ini-global-options ()
   (setf ; global options
@@ -878,7 +885,7 @@
                              (str "" (concatenate
                                         'string
                                          str
-                                        (format nil "\"~a\" ~a," (cadar k) (caddar k)))))
+                                        (format nil "'~a' ~a," (cadar k) (caddar k)))))
                             ((null k) (concatenate
                                          'string
                                          "("
@@ -996,10 +1003,9 @@
 
 
 
+;;; OTHER COMMON GNUPLOT - VTK AUXILIARY FUNCTIONS
 
 
-;;; COMMON GNUPLOT - VTK AUXILIARY FUNCTIONS
-
 (defun near-equal (a b)
   (let ((eps 10.0d-14))
     (< (abs (- a b)) eps)))
@@ -1008,18 +1014,274 @@
 ;; draw, and vtk3d to a unique list. With this piece of code,
 ;; gr2d, gr3d, draw, and model3d admit as arguments nested lists
 ;; of options and graphic objects
-(defmacro listify-arguments ()
-   '(rest ($flatten
+(defmacro listify-arguments (args)
+   `(rest ($flatten
              ($tree_reduce 
                '$append
                (cons '(mlist)
                      (map 
                        'list #'(lambda (z) (if ($listp z) z (list '(mlist) z)))
-                       args))))))
+                       ,args))))))
 
 ;; The following functions implement the marching cubes algorithm
 ;; for implicit functions in 3d.
-(simplify ($load "implicit3d.lisp"))
+(defvar *i3d_triangles*
+  '#(#(-1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 1 9 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 8 3 9 8 1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 1 2 10 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 2 10 0 2 9 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(2 8 3 2 10 8 10 9 8 -1 -1 -1 -1 -1 -1 -1)
+     #(3 11 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 11 2 8 11 0 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 9 0 2 3 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 11 2 1 9 11 9 8 11 -1 -1 -1 -1 -1 -1 -1)
+     #(3 10 1 11 10 3 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 10 1 0 8 10 8 11 10 -1 -1 -1 -1 -1 -1 -1)
+     #(3 9 0 3 11 9 11 10 9 -1 -1 -1 -1 -1 -1 -1)
+     #(9 8 10 10 8 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 7 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 3 0 7 3 4 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 1 9 8 4 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 1 9 4 7 1 7 3 1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 8 4 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 4 7 3 0 4 1 2 10 -1 -1 -1 -1 -1 -1 -1)
+     #(9 2 10 9 0 2 8 4 7 -1 -1 -1 -1 -1 -1 -1)
+     #(2 10 9 2 9 7 2 7 3 7 9 4 -1 -1 -1 -1)
+     #(8 4 7 3 11 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(11 4 7 11 2 4 2 0 4 -1 -1 -1 -1 -1 -1 -1)
+     #(9 0 1 8 4 7 2 3 11 -1 -1 -1 -1 -1 -1 -1)
+     #(4 7 11 9 4 11 9 11 2 9 2 1 -1 -1 -1 -1)
+     #(3 10 1 3 11 10 7 8 4 -1 -1 -1 -1 -1 -1 -1)
+     #(1 11 10 1 4 11 1 0 4 7 11 4 -1 -1 -1 -1)
+     #(4 7 8 9 0 11 9 11 10 11 0 3 -1 -1 -1 -1)
+     #(4 7 11 4 11 9 9 11 10 -1 -1 -1 -1 -1 -1 -1)
+     #(9 5 4 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 5 4 0 8 3 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 5 4 1 5 0 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(8 5 4 8 3 5 3 1 5 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 9 5 4 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 0 8 1 2 10 4 9 5 -1 -1 -1 -1 -1 -1 -1)
+     #(5 2 10 5 4 2 4 0 2 -1 -1 -1 -1 -1 -1 -1)
+     #(2 10 5 3 2 5 3 5 4 3 4 8 -1 -1 -1 -1)
+     #(9 5 4 2 3 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 11 2 0 8 11 4 9 5 -1 -1 -1 -1 -1 -1 -1)
+     #(0 5 4 0 1 5 2 3 11 -1 -1 -1 -1 -1 -1 -1)
+     #(2 1 5 2 5 8 2 8 11 4 8 5 -1 -1 -1 -1)
+     #(10 3 11 10 1 3 9 5 4 -1 -1 -1 -1 -1 -1 -1)
+     #(4 9 5 0 8 1 8 10 1 8 11 10 -1 -1 -1 -1)
+     #(5 4 0 5 0 11 5 11 10 11 0 3 -1 -1 -1 -1)
+     #(5 4 8 5 8 10 10 8 11 -1 -1 -1 -1 -1 -1 -1)
+     #(9 7 8 5 7 9 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 3 0 9 5 3 5 7 3 -1 -1 -1 -1 -1 -1 -1)
+     #(0 7 8 0 1 7 1 5 7 -1 -1 -1 -1 -1 -1 -1)
+     #(1 5 3 3 5 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 7 8 9 5 7 10 1 2 -1 -1 -1 -1 -1 -1 -1)
+     #(10 1 2 9 5 0 5 3 0 5 7 3 -1 -1 -1 -1)
+     #(8 0 2 8 2 5 8 5 7 10 5 2 -1 -1 -1 -1)
+     #(2 10 5 2 5 3 3 5 7 -1 -1 -1 -1 -1 -1 -1)
+     #(7 9 5 7 8 9 3 11 2 -1 -1 -1 -1 -1 -1 -1)
+     #(9 5 7 9 7 2 9 2 0 2 7 11 -1 -1 -1 -1)
+     #(2 3 11 0 1 8 1 7 8 1 5 7 -1 -1 -1 -1)
+     #(11 2 1 11 1 7 7 1 5 -1 -1 -1 -1 -1 -1 -1)
+     #(9 5 8 8 5 7 10 1 3 10 3 11 -1 -1 -1 -1)
+     #(5 7 0 5 0 9 7 11 0 1 0 10 11 10 0 -1)
+     #(11 10 0 11 0 3 10 5 0 8 0 7 5 7 0 -1)
+     #(11 10 5 7 11 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(10 6 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 5 10 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 0 1 5 10 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 8 3 1 9 8 5 10 6 -1 -1 -1 -1 -1 -1 -1)
+     #(1 6 5 2 6 1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 6 5 1 2 6 3 0 8 -1 -1 -1 -1 -1 -1 -1)
+     #(9 6 5 9 0 6 0 2 6 -1 -1 -1 -1 -1 -1 -1)
+     #(5 9 8 5 8 2 5 2 6 3 2 8 -1 -1 -1 -1)
+     #(2 3 11 10 6 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(11 0 8 11 2 0 10 6 5 -1 -1 -1 -1 -1 -1 -1)
+     #(0 1 9 2 3 11 5 10 6 -1 -1 -1 -1 -1 -1 -1)
+     #(5 10 6 1 9 2 9 11 2 9 8 11 -1 -1 -1 -1)
+     #(6 3 11 6 5 3 5 1 3 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 11 0 11 5 0 5 1 5 11 6 -1 -1 -1 -1)
+     #(3 11 6 0 3 6 0 6 5 0 5 9 -1 -1 -1 -1)
+     #(6 5 9 6 9 11 11 9 8 -1 -1 -1 -1 -1 -1 -1)
+     #(5 10 6 4 7 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 3 0 4 7 3 6 5 10 -1 -1 -1 -1 -1 -1 -1)
+     #(1 9 0 5 10 6 8 4 7 -1 -1 -1 -1 -1 -1 -1)
+     #(10 6 5 1 9 7 1 7 3 7 9 4 -1 -1 -1 -1)
+     #(6 1 2 6 5 1 4 7 8 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 5 5 2 6 3 0 4 3 4 7 -1 -1 -1 -1)
+     #(8 4 7 9 0 5 0 6 5 0 2 6 -1 -1 -1 -1)
+     #(7 3 9 7 9 4 3 2 9 5 9 6 2 6 9 -1)
+     #(3 11 2 7 8 4 10 6 5 -1 -1 -1 -1 -1 -1 -1)
+     #(5 10 6 4 7 2 4 2 0 2 7 11 -1 -1 -1 -1)
+     #(0 1 9 4 7 8 2 3 11 5 10 6 -1 -1 -1 -1)
+     #(9 2 1 9 11 2 9 4 11 7 11 4 5 10 6 -1)
+     #(8 4 7 3 11 5 3 5 1 5 11 6 -1 -1 -1 -1)
+     #(5 1 11 5 11 6 1 0 11 7 11 4 0 4 11 -1)
+     #(0 5 9 0 6 5 0 3 6 11 6 3 8 4 7 -1)
+     #(6 5 9 6 9 11 4 7 9 7 11 9 -1 -1 -1 -1)
+     #(10 4 9 6 4 10 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 10 6 4 9 10 0 8 3 -1 -1 -1 -1 -1 -1 -1)
+     #(10 0 1 10 6 0 6 4 0 -1 -1 -1 -1 -1 -1 -1)
+     #(8 3 1 8 1 6 8 6 4 6 1 10 -1 -1 -1 -1)
+     #(1 4 9 1 2 4 2 6 4 -1 -1 -1 -1 -1 -1 -1)
+     #(3 0 8 1 2 9 2 4 9 2 6 4 -1 -1 -1 -1)
+     #(0 2 4 4 2 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(8 3 2 8 2 4 4 2 6 -1 -1 -1 -1 -1 -1 -1)
+     #(10 4 9 10 6 4 11 2 3 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 2 2 8 11 4 9 10 4 10 6 -1 -1 -1 -1)
+     #(3 11 2 0 1 6 0 6 4 6 1 10 -1 -1 -1 -1)
+     #(6 4 1 6 1 10 4 8 1 2 1 11 8 11 1 -1)
+     #(9 6 4 9 3 6 9 1 3 11 6 3 -1 -1 -1 -1)
+     #(8 11 1 8 1 0 11 6 1 9 1 4 6 4 1 -1)
+     #(3 11 6 3 6 0 0 6 4 -1 -1 -1 -1 -1 -1 -1)
+     #(6 4 8 11 6 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(7 10 6 7 8 10 8 9 10 -1 -1 -1 -1 -1 -1 -1)
+     #(0 7 3 0 10 7 0 9 10 6 7 10 -1 -1 -1 -1)
+     #(10 6 7 1 10 7 1 7 8 1 8 0 -1 -1 -1 -1)
+     #(10 6 7 10 7 1 1 7 3 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 6 1 6 8 1 8 9 8 6 7 -1 -1 -1 -1)
+     #(2 6 9 2 9 1 6 7 9 0 9 3 7 3 9 -1)
+     #(7 8 0 7 0 6 6 0 2 -1 -1 -1 -1 -1 -1 -1)
+     #(7 3 2 6 7 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(2 3 11 10 6 8 10 8 9 8 6 7 -1 -1 -1 -1)
+     #(2 0 7 2 7 11 0 9 7 6 7 10 9 10 7 -1)
+     #(1 8 0 1 7 8 1 10 7 6 7 10 2 3 11 -1)
+     #(11 2 1 11 1 7 10 6 1 6 7 1 -1 -1 -1 -1)
+     #(8 9 6 8 6 7 9 1 6 11 6 3 1 3 6 -1)
+     #(0 9 1 11 6 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(7 8 0 7 0 6 3 11 0 11 6 0 -1 -1 -1 -1)
+     #(7 11 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(7 6 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 0 8 11 7 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 1 9 11 7 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(8 1 9 8 3 1 11 7 6 -1 -1 -1 -1 -1 -1 -1)
+     #(10 1 2 6 11 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 3 0 8 6 11 7 -1 -1 -1 -1 -1 -1 -1)
+     #(2 9 0 2 10 9 6 11 7 -1 -1 -1 -1 -1 -1 -1)
+     #(6 11 7 2 10 3 10 8 3 10 9 8 -1 -1 -1 -1)
+     #(7 2 3 6 2 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(7 0 8 7 6 0 6 2 0 -1 -1 -1 -1 -1 -1 -1)
+     #(2 7 6 2 3 7 0 1 9 -1 -1 -1 -1 -1 -1 -1)
+     #(1 6 2 1 8 6 1 9 8 8 7 6 -1 -1 -1 -1)
+     #(10 7 6 10 1 7 1 3 7 -1 -1 -1 -1 -1 -1 -1)
+     #(10 7 6 1 7 10 1 8 7 1 0 8 -1 -1 -1 -1)
+     #(0 3 7 0 7 10 0 10 9 6 10 7 -1 -1 -1 -1)
+     #(7 6 10 7 10 8 8 10 9 -1 -1 -1 -1 -1 -1 -1)
+     #(6 8 4 11 8 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 6 11 3 0 6 0 4 6 -1 -1 -1 -1 -1 -1 -1)
+     #(8 6 11 8 4 6 9 0 1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 4 6 9 6 3 9 3 1 11 3 6 -1 -1 -1 -1)
+     #(6 8 4 6 11 8 2 10 1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 3 0 11 0 6 11 0 4 6 -1 -1 -1 -1)
+     #(4 11 8 4 6 11 0 2 9 2 10 9 -1 -1 -1 -1)
+     #(10 9 3 10 3 2 9 4 3 11 3 6 4 6 3 -1)
+     #(8 2 3 8 4 2 4 6 2 -1 -1 -1 -1 -1 -1 -1)
+     #(0 4 2 4 6 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 9 0 2 3 4 2 4 6 4 3 8 -1 -1 -1 -1)
+     #(1 9 4 1 4 2 2 4 6 -1 -1 -1 -1 -1 -1 -1)
+     #(8 1 3 8 6 1 8 4 6 6 10 1 -1 -1 -1 -1)
+     #(10 1 0 10 0 6 6 0 4 -1 -1 -1 -1 -1 -1 -1)
+     #(4 6 3 4 3 8 6 10 3 0 3 9 10 9 3 -1)
+     #(10 9 4 6 10 4 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 9 5 7 6 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 4 9 5 11 7 6 -1 -1 -1 -1 -1 -1 -1)
+     #(5 0 1 5 4 0 7 6 11 -1 -1 -1 -1 -1 -1 -1)
+     #(11 7 6 8 3 4 3 5 4 3 1 5 -1 -1 -1 -1)
+     #(9 5 4 10 1 2 7 6 11 -1 -1 -1 -1 -1 -1 -1)
+     #(6 11 7 1 2 10 0 8 3 4 9 5 -1 -1 -1 -1)
+     #(7 6 11 5 4 10 4 2 10 4 0 2 -1 -1 -1 -1)
+     #(3 4 8 3 5 4 3 2 5 10 5 2 11 7 6 -1)
+     #(7 2 3 7 6 2 5 4 9 -1 -1 -1 -1 -1 -1 -1)
+     #(9 5 4 0 8 6 0 6 2 6 8 7 -1 -1 -1 -1)
+     #(3 6 2 3 7 6 1 5 0 5 4 0 -1 -1 -1 -1)
+     #(6 2 8 6 8 7 2 1 8 4 8 5 1 5 8 -1)
+     #(9 5 4 10 1 6 1 7 6 1 3 7 -1 -1 -1 -1)
+     #(1 6 10 1 7 6 1 0 7 8 7 0 9 5 4 -1)
+     #(4 0 10 4 10 5 0 3 10 6 10 7 3 7 10 -1)
+     #(7 6 10 7 10 8 5 4 10 4 8 10 -1 -1 -1 -1)
+     #(6 9 5 6 11 9 11 8 9 -1 -1 -1 -1 -1 -1 -1)
+     #(3 6 11 0 6 3 0 5 6 0 9 5 -1 -1 -1 -1)
+     #(0 11 8 0 5 11 0 1 5 5 6 11 -1 -1 -1 -1)
+     #(6 11 3 6 3 5 5 3 1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 10 9 5 11 9 11 8 11 5 6 -1 -1 -1 -1)
+     #(0 11 3 0 6 11 0 9 6 5 6 9 1 2 10 -1)
+     #(11 8 5 11 5 6 8 0 5 10 5 2 0 2 5 -1)
+     #(6 11 3 6 3 5 2 10 3 10 5 3 -1 -1 -1 -1)
+     #(5 8 9 5 2 8 5 6 2 3 8 2 -1 -1 -1 -1)
+     #(9 5 6 9 6 0 0 6 2 -1 -1 -1 -1 -1 -1 -1)
+     #(1 5 8 1 8 0 5 6 8 3 8 2 6 2 8 -1)
+     #(1 5 6 2 1 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 3 6 1 6 10 3 8 6 5 6 9 8 9 6 -1)
+     #(10 1 0 10 0 6 9 5 0 5 6 0 -1 -1 -1 -1)
+     #(0 3 8 5 6 10 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(10 5 6 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(11 5 10 7 5 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(11 5 10 11 7 5 8 3 0 -1 -1 -1 -1 -1 -1 -1)
+     #(5 11 7 5 10 11 1 9 0 -1 -1 -1 -1 -1 -1 -1)
+     #(10 7 5 10 11 7 9 8 1 8 3 1 -1 -1 -1 -1)
+     #(11 1 2 11 7 1 7 5 1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 1 2 7 1 7 5 7 2 11 -1 -1 -1 -1)
+     #(9 7 5 9 2 7 9 0 2 2 11 7 -1 -1 -1 -1)
+     #(7 5 2 7 2 11 5 9 2 3 2 8 9 8 2 -1)
+     #(2 5 10 2 3 5 3 7 5 -1 -1 -1 -1 -1 -1 -1)
+     #(8 2 0 8 5 2 8 7 5 10 2 5 -1 -1 -1 -1)
+     #(9 0 1 5 10 3 5 3 7 3 10 2 -1 -1 -1 -1)
+     #(9 8 2 9 2 1 8 7 2 10 2 5 7 5 2 -1)
+     #(1 3 5 3 7 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 7 0 7 1 1 7 5 -1 -1 -1 -1 -1 -1 -1)
+     #(9 0 3 9 3 5 5 3 7 -1 -1 -1 -1 -1 -1 -1)
+     #(9 8 7 5 9 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(5 8 4 5 10 8 10 11 8 -1 -1 -1 -1 -1 -1 -1)
+     #(5 0 4 5 11 0 5 10 11 11 3 0 -1 -1 -1 -1)
+     #(0 1 9 8 4 10 8 10 11 10 4 5 -1 -1 -1 -1)
+     #(10 11 4 10 4 5 11 3 4 9 4 1 3 1 4 -1)
+     #(2 5 1 2 8 5 2 11 8 4 5 8 -1 -1 -1 -1)
+     #(0 4 11 0 11 3 4 5 11 2 11 1 5 1 11 -1)
+     #(0 2 5 0 5 9 2 11 5 4 5 8 11 8 5 -1)
+     #(9 4 5 2 11 3 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(2 5 10 3 5 2 3 4 5 3 8 4 -1 -1 -1 -1)
+     #(5 10 2 5 2 4 4 2 0 -1 -1 -1 -1 -1 -1 -1)
+     #(3 10 2 3 5 10 3 8 5 4 5 8 0 1 9 -1)
+     #(5 10 2 5 2 4 1 9 2 9 4 2 -1 -1 -1 -1)
+     #(8 4 5 8 5 3 3 5 1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 4 5 1 0 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(8 4 5 8 5 3 9 0 5 0 3 5 -1 -1 -1 -1)
+     #(9 4 5 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 11 7 4 9 11 9 10 11 -1 -1 -1 -1 -1 -1 -1)
+     #(0 8 3 4 9 7 9 11 7 9 10 11 -1 -1 -1 -1)
+     #(1 10 11 1 11 4 1 4 0 7 4 11 -1 -1 -1 -1)
+     #(3 1 4 3 4 8 1 10 4 7 4 11 10 11 4 -1)
+     #(4 11 7 9 11 4 9 2 11 9 1 2 -1 -1 -1 -1)
+     #(9 7 4 9 11 7 9 1 11 2 11 1 0 8 3 -1)
+     #(11 7 4 11 4 2 2 4 0 -1 -1 -1 -1 -1 -1 -1)
+     #(11 7 4 11 4 2 8 3 4 3 2 4 -1 -1 -1 -1)
+     #(2 9 10 2 7 9 2 3 7 7 4 9 -1 -1 -1 -1)
+     #(9 10 7 9 7 4 10 2 7 8 7 0 2 0 7 -1)
+     #(3 7 10 3 10 2 7 4 10 1 10 0 4 0 10 -1)
+     #(1 10 2 8 7 4 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 9 1 4 1 7 7 1 3 -1 -1 -1 -1 -1 -1 -1)
+     #(4 9 1 4 1 7 0 8 1 8 7 1 -1 -1 -1 -1)
+     #(4 0 3 7 4 3 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(4 8 7 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(9 10 8 10 11 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 0 9 3 9 11 11 9 10 -1 -1 -1 -1 -1 -1 -1)
+     #(0 1 10 0 10 8 8 10 11 -1 -1 -1 -1 -1 -1 -1)
+     #(3 1 10 11 3 10 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 2 11 1 11 9 9 11 8 -1 -1 -1 -1 -1 -1 -1)
+     #(3 0 9 3 9 11 1 2 9 2 11 9 -1 -1 -1 -1)
+     #(0 2 11 8 0 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(3 2 11 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(2 3 8 2 8 10 10 8 9 -1 -1 -1 -1 -1 -1 -1)
+     #(9 10 2 0 9 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(2 3 8 2 8 10 0 1 8 1 10 8 -1 -1 -1 -1)
+     #(1 10 2 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(1 3 8 9 1 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 9 1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(0 3 8 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)
+     #(-1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1 -1)) )
 
 ; Copies multidimensional arrays.
 (defun copy-array (array)
@@ -1140,3 +1402,40 @@
       (setf oldval (copy-array newval)))
     vert))
 
+
+
+
+
+
+;; This is the function to be called at Maxima level.
+;; Some examples:
+;;   draw(gr2d(opt & obj))$ => a 2d plot, equivalent to draw2d(opt & obj)
+;;   draw(gr3d(opt & obj))$ => a 2d plot, equivalent to draw3d(opt & obj)
+;;   draw(gr2d(opt & obj),gr2d(opt & obj),gr3d(opt & obj),gr2d(opt & obj))$
+;;                            => four plots in one column, one of them is a 3d plot
+;;   draw(terminal=png,columns=2,gr2d(opt & obj),gr3d(opt & obj))
+;;                            => png file with two plots (2d and 3d) side by side
+;; See bellow for $draw2d and $draw3d
+(defun $draw (&rest args)
+  (cond ((or (equal $draw_renderer '$gnuplot)
+             (equal $draw_renderer '$gnuplot_pipes))
+           (apply 'draw_gnuplot args))
+        ((equal $draw_renderer '$vtk)
+           (apply 'draw_vtk args))
+        (t
+           (merror "draw: unknown renderer ~M" $draw_renderer))))
+
+;; Equivalent to draw2d(opt & obj)
+(defun $draw2d (&rest args)
+   ($draw (cons '($gr2d) args)) )
+
+;; Equivalent to draw3d(opt & obj)
+(defun $draw3d (&rest args)
+  (cond ((or (equal $draw_renderer '$gnuplot)
+             (equal $draw_renderer '$gnuplot_pipes))
+           (draw_gnuplot (cons '($gr3d) args)))
+        ((equal $draw_renderer '$vtk)
+           (draw_vtk (cons '($gr3d) args)))
+        (t
+           (merror "draw: unknown renderer ~M" $draw_renderer))))
+
