@@ -19,8 +19,6 @@
 (loop for (x y) on '(%cot %tan %csc %sin %sec %cos %coth %tanh %csch %sinh %sech %cosh)
    by #'cddr do (putprop x y 'recip) (putprop y x 'recip))
 
-(defun nill () '(nil))
-
 (defmvar $zeta%pi t)
 
 ;; polynomial predicates and other such things
@@ -727,9 +725,7 @@ summation when necessary."
 ;; multiplication of sums
 
 (defun gensumindex ()
-  (implode (nconc (exploden $genindex)
-		  (and $gensumnum
-		       (mexploden (setq $gensumnum (1+ $gensumnum)))))))
+  (intern (format nil "~S~D" $genindex (incf $gensumnum))))
 
 (defun sumtimes (x y)
   (cond ((null x) y)
@@ -834,7 +830,7 @@ summation when necessary."
       ((null l)
        (cons (simplifya (cons (list (caar e)) a) nil)
 	     (simplifya (cons (list (caar e)) b) nil)))
-    (if (or (mnump (car l)) (constant (car l)))
+    (if ($constantp (car l))
 	(setq a (cons (car l) a))
 	(setq b (cons (car l) b)))))
 
@@ -906,29 +902,29 @@ summation when necessary."
 	       (return (rplacd l (cddr l))))))))
 
 (defun additive (e z)
-  (cond ((get (caar e) '$outative)	;Really a linearize!
-	 (setq opers-list (copy-list opers-list ))
-	 (rem-opers-p '$outative)
-	 (linearize1 e z))
-	((mplusp (cadr e))
-	 (addn (mapcar #'(lambda (q)
-			   (oper-apply (list* (car e) q (cddr e)) z))
-		       (cdr (cadr e)))
-	       z))
-	(t (oper-apply e z))))
+  (cond ((get (caar e) '$outative)  ; Really a linearize!
+         (setq opers-list (copy-list opers-list))
+         (rem-opers-p '$outative)
+         (linearize1 e z))
+        ((mplusp (cadr e))
+         (addn (mapcar #'(lambda (q)
+                           (let ((opers-list *opers-list))
+                             (oper-apply (list* (car e) q (cddr e)) z)))
+                       (cdr (cadr e)))
+               z))
+        (t (oper-apply e z))))
 
 (setq opers (cons '$multiplicative opers)
       *opers-list (cons '($multiplicative . multiplicative) *opers-list))
 
 (defun multiplicative (e z)
   (cond ((mtimesp (cadr e))
-	 (simptimes
-	  (cons '(mtimes)
-		(mapcar #'(lambda (q)
-			    (oper-apply (list* (car e) q (cddr e)) z))
-			(cdr (cadr e))))
-	  1 z))
-	(t (oper-apply e z))))
+         (muln (mapcar #'(lambda (q)
+                           (let ((opers-list *opers-list))
+                             (oper-apply (list* (car e) q (cddr e)) z)))
+                       (cdr (cadr e)))
+               z))
+        (t (oper-apply e z))))
 
 (setq opers (cons '$outative opers)
       *opers-list (cons '($outative . outative) *opers-list))
@@ -997,28 +993,28 @@ summation when necessary."
 (setq opers (cons '$antisymmetric opers)
       *opers-list (cons '($antisymmetric . antisym) *opers-list))
 
-(declare-top (special sign))
+(declare-top (special antisym-sign))
 
 (defmfun antisym (e z)
   (let ((l (mapcar #'(lambda (q) (simpcheck q z)) (cdr e))))
-    (let (sign) (if (or (not (eq (caar e) 'mnctimes)) (freel l 'mnctimes))
+    (let (antisym-sign) (if (or (not (eq (caar e) 'mnctimes)) (freel l 'mnctimes))
 		    (setq l (bbsort1 l)))
 	 (cond ((equal l 0) 0)
-	       ((prog1 (null sign) (setq e (oper-apply (cons (car e) l) t)))
+	       ((prog1 (null antisym-sign) (setq e (oper-apply (cons (car e) l) t)))
 		e)
 	       (t (neg e))))))
 
 (defun bbsort1 (l)
   (prog (sl sl1)
      (if (or (null l) (null (cdr l))) (return l))
-     (setq sign nil sl (list nil (car l)))
+     (setq antisym-sign nil sl (list nil (car l)))
      loop (setq l (cdr l))
      (if (null l) (return (nreverse (cdr sl))))
      (setq sl1 sl)
      loop1(cond ((null (cdr sl1)) (rplacd sl1 (cons (car l) nil)))
 		((alike1 (car l) (cadr sl1)) (return 0))
 		((great (car l) (cadr sl1)) (rplacd sl1 (cons (car l) (cdr sl1))))
-		(t (setq sign (not sign) sl1 (cdr sl1)) (go loop1)))
+		(t (setq antisym-sign (not antisym-sign) sl1 (cdr sl1)) (go loop1)))
      (go loop)))
 
 (setq opers (cons '$nary opers)
@@ -1045,19 +1041,23 @@ summation when necessary."
       *opers-list (cons '($lassociative . lassociative) *opers-list))
 
 (defmfun lassociative (e z)
-  (let ((ans (cdr (oper-apply (cons (car e) (total-nary e)) z))))
-    (cond ((null (cddr ans)) (cons (car e) ans))
-	  ((do ((newans (list (car e) (car ans) (cadr ans))
-			(list (car e) newans (car ans)))
-		(ans (cddr ans) (cdr ans)))
-	       ((null ans) newans))))))
+  (let*
+    ((ans0 (oper-apply (cons (car e) (total-nary e)) z))
+     (ans (cdr ans0)))
+    (cond ((or (null (cddr ans)) (not (eq (caar ans0) (caar e)))) ans0)
+          ((do ((newans (list (car e) (car ans) (cadr ans))
+                        (list (car e) newans (car ans)))
+                (ans (cddr ans) (cdr ans)))
+               ((null ans) newans))))))
 
 (setq opers (cons '$rassociative opers)
       *opers-list (cons '($rassociative . rassociative) *opers-list))
 
 (defmfun rassociative (e z)
-  (let ((ans (cdr (oper-apply (cons (car e) (total-nary e)) z))))
-    (cond ((null (cddr ans)) (cons (car e) ans))
+  (let*
+    ((ans0 (oper-apply (cons (car e) (total-nary e)) z))
+     (ans (cdr ans0)))
+    (cond ((or (null (cddr ans)) (not (eq (caar ans0) (caar e)))) ans0)
 	  (t (setq ans (nreverse ans))
 	     (do ((newans (list (car e) (cadr ans) (car ans))
 			  (list (car e) (car ans) newans))
