@@ -9,6 +9,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (in-package :maxima)
+
 (macsyma-module buildq)
 
 ;; Exported functions are $BUILDQ and MBUILDQ-SUBST
@@ -20,12 +21,10 @@
 ;;******                                                              ******
 ;;**************************************************************************
 
-
-
 ;;DESCRIPTION:
 
 
-;; Syntax: 
+;; Syntax:
 
 ;; BUILDQ([<varlist>],<expression>);
 
@@ -37,15 +36,11 @@
 
 ;; the <value>s in the <varlist> are evaluated left to right (the syntax
 ;; <atom> is equivalent to <atom>:<atom>).  then these values are substituted
-;; into <expression> in parallel.  If any <atom> appears as a single 
+;; into <expression> in parallel.  If any <atom> appears as a single
 ;; argument to the special form SPLICE (i.e. SPLICE(<atom>) ) inside
 ;; <expression>, then the value associated with that <atom> must be a macsyma
 ;; list, and it is spliced into <expression> instead of substituted.
 
-
-
-
-
 ;;SIMPLIFICATION:
 
 
@@ -58,8 +53,7 @@
 ;; This is modeled after SIMPMDEF, SIMPLAMBDA etc. in JM;SIMP >
 
 (defun simpbuildq (x *ignore* simp-flags)
-  *ignore*			      ; no simplification takes place.
-  simp-flags				; ditto.
+  (declare (ignore *ignore* simp-flags))
   (cons '($buildq simp) (cdr x)))
 
 ;; Note that supression of simplification is very important to the semantics
@@ -76,7 +70,7 @@
 (defmspec $buildq (form) (setq form (cdr form))
 	  (cond ((or (null (cdr form))
 		     (cddr form))
-		 (merror "`buildq' takes 2 args:~%~M" `(($buildq) ,@form)))
+		 (merror (intl:gettext "buildq: expected exactly two arguments; found ~M") `(($buildq) ,@form)))
 		(t (mbuildq (car form) (cadr form)))))
 
 ;; this macro definition is NOT equivalent because of the way lisp macros
@@ -100,7 +94,7 @@
 
 (defun mbuildq (substitutions expression)
   (cond ((not ($listp substitutions))
-	 (merror "First arg to `buildq' not a list: ~M" substitutions)))
+	 (merror (intl:gettext "buildq: first argument must be a list; found ~M") substitutions)))
   (mbuildq-subst
    (mapcar #'(lambda (form)             ; make a variable/value alist
 	       (cond ((symbolp form)
@@ -108,8 +102,8 @@
 		     ((and (eq (caar form) 'msetq)
 			   (symbolp (cadr form)))
 		      (cons (cadr form) (meval (caddr form))))
-		     (t 
-		      (merror "Illegal form in variable list--`buildq': ~M"
+		     (t
+		      (merror (intl:gettext "buildq: variable must be a symbol or an assignment to a symbol; found ~M")
 			      form
 			      ))))
 	   (cdr substitutions))
@@ -130,8 +124,8 @@
 	   ((mbuildq-splice-associate expression alist)
 					; if the expression is a legal SPLICE, this clause is taken.
 					; a SPLICE should never occur here.  It corresponds to `,@form
-	      
-	    (merror "`splice' used in illegal context: ~M" expression))
+
+	    (merror (intl:gettext "splice: encountered 'splice' in an unexpected place: ~M") expression))
 	   ((atom (caar expression))
 	    (setq new-car (mbuildq-associate (caar expression) alist))
 	    (cond ((eq new-car (caar expression))
@@ -142,7 +136,7 @@
 		       `(,(cons 'mqapply (cdar expression))
 			 ,new-car
 			 ,@(mbuildq-subst alist (cdr expression)))))))
-	   ((setq new-car 
+	   ((setq new-car
 		  (mbuildq-splice-associate (car expression) alist))
 	    (return (append (cdr new-car)
 			    (mbuildq-subst alist (cdr expression)))))
@@ -154,7 +148,6 @@
 		expression)
 	       (t (cons new-car new-cdr)))))))
 
-
 ;; this function returns the appropriate thing to substitute for an atom
 ;; appearing inside a backquote.  If it's not in the varlist, it's the
 ;; atom itself.
@@ -163,14 +156,14 @@
   (let ((form))
     (cond ((not (symbolp atom))
 	   atom)
-	  ((setq form (assq atom alist))
+	  ((setq form (assoc atom alist :test #'eq))
 	   (cdr form))
-	  ((setq form (assq ($verbify atom) alist))
+	  ((setq form (assoc ($verbify atom) alist :test #'eq))
 					;trying to match a nounified substitution variable
 	   (cond ((atom (cdr form))
 		  ($nounify (cdr form)))
-		 ((memq (caar (cdr form)) 
-			'(mquote mlist mprog mprogn lambda))
+		 ((member (caar (cdr form))
+			'(mquote mlist mprog mprogn lambda) :test #'eq)
 					;list gotten from the parser.
 		  `((mquote) ,(cdr form)))
 		 (t `( (,($nounify (caar (cdr form)))
@@ -183,16 +176,16 @@
 ;; the basic philosophy is that the SPLICE is ours if it has exactly
 ;; one symbolic argument and that arg appears in the current varlist.
 ;; if it's one of ours, this function returns the list it's bound to.
-;; otherwise it returns nil.  Notice that the list returned is an 
+;; otherwise it returns nil.  Notice that the list returned is an
 ;; MLIST and hence the cdr of the return value is what gets spliced in.
 
 (defun mbuildq-splice-associate (expression alist)
   (and (eq (caar expression) '$splice)
        (cdr expression)
        (null (cddr expression))
-       (let ((match (assq (cadr expression) alist)))
+       (let ((match (assoc (cadr expression) alist :test #'eq)))
 	 (cond ((null match) () )
 	       ((not ($listp (cdr match)))
-		(merror "~M returned ~M~%But `splice' must return a list"
+		(merror (intl:gettext "buildq: 'splice' must return a list, but ~M returned: ~M~%")
 			expression (cdr match)))
 	       (t (cdr match))))))
