@@ -64,7 +64,7 @@
        ((and (equal ($imagpart (setq z (div* x '$%i))) 0)
 	     (setq y ($asksign z)))
 	(cond
-	  ((equal y '$zero) (merror (intl:gettext "plog(0) is undefined.")))
+	  ((equal y '$zero) (merror (intl:gettext "plog: plog(0) is undefined.")))
 	  (t (cond ((eq y '$pos) (setq y 1))
 		   ((eq y '$neg) (setq y -1)))
 	     (return (add2* (simpln (list '(%log)
@@ -733,8 +733,8 @@
 	     (mul2 d b1)))))
 
 (declare-top (special $globalsolve $backsubst $dispflag
-		      $linsolve_params $%rnum_list ax linelable $linechar 
-		      $linenum sol *mosesflag))
+		      $linsolve_params $%rnum_list ax *linelabel* $linechar 
+		      $linenum *mosesflag))
 
 (defun xrutout (ax n m varl ind)
   (let (($linsolve_params (and $backsubst $linsolve_params)))
@@ -773,20 +773,20 @@
        (do ((ll zz (cdr ll)))
 	   ((null ll))
 	 (setq zzz (car ll))
-	 (setq zzz (list '(mlable)
+	 (setq zzz (list '(mlabel)
 			 (progn
 			   (if chk
 			       (setq chk nil)
 			       (incf $linenum))
 			   (let (($nolabels nil))
 			     (makelabel $linechar))
-			   linelable)
-			 (set linelable zzz)))
-	 (nconc sol (ncons linelable))
+			   *linelabel*)
+			 (set *linelabel* zzz)))
+	 (nconc sol (ncons *linelabel*))
 	 (cond ($dispflag
 		(setq tim (get-internal-run-time))
 		(mtell-open "~%~M" zzz)
 		(timeorg tim))
 	       (t
-		(putprop linelable t 'nodisp))))
+		(putprop *linelabel* t 'nodisp))))
        (return sol))))
