@@ -179,14 +179,12 @@
 		    (break-call (car r) (cdr r) 'break-command)
 		    (go top)))))
 	(format t "~a" *general-display-prefix*)
-	(cond (#.writefilep  ;write out the c line to the dribble file
-	       (let ((#.ttyoff t))
-		 (displa `((mlabel) , c-tag , $__)))))
 	(if (eq r eof) (return '$done))
 	(setq $__ (caddr r))
 	(unless $nolabels (set  c-tag $__))
 	(cond (batch-or-demo-flag
-	       (displa `((mlabel) ,c-tag , $__))))
+	  (let (($display2d nil))
+	    (displa `((mlabel) ,c-tag , $__)))))
 	(setq time-before (get-internal-run-time)
 	      etime-before (get-internal-real-time))
 	(setq area-before (used-area))
