@@ -56,7 +56,7 @@
 ;; in case a file-name is supplied, the output will be sent
 ;; (perhaps appended) to that file.
 
-(declare-top (special lop rop ccol $gcprint texport $labels $inchar vaxima-main-dir))
+(declare-top (special lop rop $labels $inchar))
 
 (defvar *tex-environment-default* '("$$" . "$$"))
 
@@ -96,7 +96,7 @@
 (setf (get 'mdefmacro 'tex-environment)
       `(,(format nil "~%\\begin{verbatim}~%") . ,(format nil ";~%\\end{verbatim}~%")))
 
-(setf (get 'mlable 'tex-environment)
+(setf (get 'mlabel 'tex-environment)
       `(,(format nil "~%\\begin{verbatim}~%") . ,(format nil ";~%\\end{verbatim}~%")))
 
 ;; top level command the result of tex'ing the expression x.
@@ -123,9 +123,8 @@
       strsym)))
 
 (defun tex1 (mexplabel &optional filename-or-stream) ;; mexplabel, and optional filename or stream
-  (prog (mexp  texport $gcprint ccol x y itsalabel need-to-close-texport)
-     ;; $gcprint = nil turns gc messages off
-     (setq ccol 1)
+  (prog (mexp  texport x y itsalabel need-to-close-texport)
+     (reset-ccol)
      (cond ((null mexplabel)
 	    (displa " No eqn given to TeX")
 	    (return nil)))
@@ -181,15 +180,15 @@
 	       (string= (subseq (maybe-invert-string-case (string $outchar)) 1 (length (string $outchar)))
 			(subseq (string mexplabel) 1 (length (string $outchar)))))))
 	    ;; aha, this is a C-line: do the grinding:
-	    (format texport (car (get-tex-environment 'mlable)))
+	    (format texport (car (get-tex-environment 'mlabel)))
         (format texport "~a" mexplabel)
 	    (mgrind mexp texport)	;write expression as string
-	    (format texport (cdr (get-tex-environment 'mlable))))
+	    (format texport (cdr (get-tex-environment 'mlabel))))
 	   (t 
 	    (if mexplabel (setq mexplabel (quote-% mexplabel)))
 					; display the expression for TeX now:
-        (myprinc (car (get-tex-environment mexp)))
-	    (mapc #'myprinc
+        (myprinc (car (get-tex-environment mexp)) texport)
+	    (mapc #'(lambda (x) (myprinc x texport))
 		  ;;initially the left and right contexts are
 		  ;; empty lists, and there are implicit parens
 		  ;; around the whole expression
@@ -214,22 +213,20 @@
 ;;-              that a value is all printed on one line (and not divided
 ;;-              by the crazy top level os routines)
 
-(defun myprinc (chstr)
-  (prog (chlst)
-     (cond ((and (> (+ (length (setq chlst (exploden chstr))) ccol) 70.)
-                 (or (stringp chstr) (equal chstr '| |)))
-	    (terpri texport)      ;would have exceeded the line length
-	    (setq ccol 1.)
-	    (myprinc " "))) ; lead off with a space for safetyso we split it up.			
-     (do ((ch chlst (cdr ch))
-	  (colc ccol (1+ colc)))
-	 ((null ch) (setq ccol colc))
-       (write-char (car ch) texport))))
+(let ((ccol 1))
+  (defun reset-ccol () (setq ccol 1))
 
-(defun myterpri nil
-  (cond (texport (terpri texport))
-	(t (mterpri)))
-  (setq ccol 1))
+  (defun myprinc (chstr texport)
+    (prog (chlst)
+       (cond ((and (> (+ (length (setq chlst (exploden chstr))) ccol) 70.)
+                   (or (stringp chstr) (equal chstr '| |)))
+	      (terpri texport)      ;would have exceeded the line length
+	      (setq ccol 1.)
+	      (myprinc " " texport))) ; lead off with a space for safetyso we split it up.			
+       (do ((ch chlst (cdr ch))
+	    (colc ccol (1+ colc)))
+	   ((null ch) (setq ccol colc))
+         (write-char (car ch) texport)))))
 
 (defun tex (x l r lop rop)
   ;; x is the expression of interest; l is the list of strings to its
@@ -466,7 +463,12 @@
 (defprop $alpha "\\alpha" texword)
 (defprop $beta "\\beta" texword)
 (defprop $gamma "\\gamma" texword)
-(defprop %gamma "\\Gamma" texword)  ; THIS IS UNFORTUNATE ...
+(defprop %gamma "\\gamma" texword)
+
+(defprop %gamma tex-gamma tex)
+(defun tex-gamma (x l r)
+ (tex (cadr x) (append l '("\\Gamma\\left(")) (append '("\\right)") r) 'mparen 'mparen))
+
 (defprop $%gamma "\\gamma" texword)
 (defprop $delta "\\delta" texword)
 (defprop $epsilon "\\varepsilon" texword)
@@ -1027,7 +1029,7 @@
 
 (defprop mtext tex-mtext tex)
 (defprop text-string tex-mtext tex)
-(defprop mlable tex-mlable tex)
+(defprop mlabel tex-mlabel tex)
 (defprop spaceout tex-spaceout tex)
 
 ;; Additions by Marek Rychlik (rychlik@u.arizona.edu)
@@ -1046,7 +1048,7 @@
 (defun tex-mtext (x l r)
   (tex-list (map 'list #'tex-try-sym (cdr x)) l r ""))
 
-(defun tex-mlable (x l r)
+(defun tex-mlabel (x l r)
   (tex (caddr x)
        (append l
 	       (if (cadr x)
