@@ -318,7 +318,8 @@
 			  #:rationalize
 			  #:coerce
 			  )
-  (:export #:lentz))
+  (:export #:lentz
+	   #:sum-power-series))
 
 ;; Export all the external symbols in BIGFLOAT-IMPL from BIGFLOAT too.
 (do-external-symbols (s '#:bigfloat-impl)
