@@ -87,18 +87,10 @@
 ;; these are in the system package in gcl...
 #-gcl
 (progn 'compile
-       ;; return path as a string  or nil if none.
-       ;;#+nil
-       ;;(defun stream-name (path)
-       ;;  (let ((tem (errset (namestring (pathname path)))))
-       ;;    (car tem)))
-
        (defun break-call (key args prop &aux fun)
 	 (setq fun (complete-prop key 'keyword prop))
 	 (setq key fun)
 	 (or fun (return-from break-call nil))
-                       ; jfa commented out the following line. Did it ever work?
-                       ; #+clisp (eval '(setq *break-env* (the-environment)))
 	 (setq fun (get fun prop))
 	 (unless (symbolp fun)
 	   (let ((gen (gensym)))
@@ -375,24 +367,6 @@
 	      (unread-char next-char stream)))
 	   result))))
 
-(defun grab-line-number (li stream)
-  (declare (type (vector #.(array-element-type "ab")) li))
-  (cond ((and (> (length li) 3)
-	      (digit-char-p (aref li 1)))
-	 (let ((in (get-instream stream)))
-	   (and in
-		(progn
-		  (multiple-value-bind
-			(line pos)
-		      (read-from-string li nil nil)
-		    (let ((file (read-from-string li nil nil
-						  :start pos)))
-		      (cond ((and (stringp file) (fixnump line))
-			     (setf (instream-stream-name in)
-				   file)
-			     (setf (instream-line in)
-				   line)))))))))))
-
 (defvar *break-level* nil)
 (defvar *break-env* nil)
 (defvar *top-eof* (cons nil nil))
@@ -445,6 +419,8 @@
 							 (cdr res) 
 				                         'break-command)))
 				  (cond ((eq value :resume) (return)))))
+			       ((eq res *top-eof*)
+			        (funcall (get :top 'break-command)))
 			       (t
 				(setq $__ (nth 2 res))
 				(setq $% (meval* $__))
