@@ -31,9 +31,9 @@
 		       varlist genvar
 		       $gensumnum checkfactors $features featurel
 		       $weightlevels tellratlist $dontfactor
-		       dispflag savefile $%% $error smart-tty
+		       dispflag savefile $%% $error
 		       opers *ratweights $ratweights
-		       $stringdisp $lispdisp defaultf command
+		       $stringdisp $lispdisp command
 		       transp $contexts $setcheck $macros autoload))
 
 (mapc #'(lambda (x) (setf (symbol-value (car x))
@@ -55,7 +55,7 @@
 (defvar lessorder nil)
 (defvar greatorder nil)
 (defvar *in-translate-file* nil)
-(defvar linelable nil)
+(defvar *linelabel* nil)
 (defvar rephrase nil)
 (defvar st nil)
 (defvar oldst nil)
@@ -107,14 +107,10 @@
 
 (defmvar user-timesofar nil)
 
-(defmvar aliaslist nil
-  "is used by the `makeatomic' scheme which has never been completed"
-  no-reset)
-
 ;; This version of meval* makes sure, that the facts from the global variable
-;; locals are cleared with a call to clearsign. The facts are added by asksign
-;; and friends. The function meval* is only used for top level evaluations.
-;; For other cases the function meval can be used.
+;; *local-signs* are cleared with a call to clearsign. The facts are added by
+;; asksign and friends. The function meval* is only used for top level
+;; evaluations.  For other cases the function meval can be used.
 
 (defmvar $ratvarswitch t) ; If T, start an evaluation with a fresh list VARLIST.
 
@@ -128,17 +124,17 @@
     (clearsign)))
 
 (defmfun makelabel (x)
-  (setq linelable ($concat '|| x $linenum))
+  (setq *linelabel* ($concat '|| x $linenum))
   (unless $nolabels
     (when (or (null (cdr $labels))
-	      (when (member linelable (cddr $labels) :test #'equal)
-		(setf $labels (delete linelable $labels :count 1 :test #'eq)) t)
-	      (not (eq linelable (cadr $labels))))
-      (setq $labels (cons (car $labels) (cons linelable (cdr $labels))))))
-  linelable)
+	      (when (member *linelabel* (cddr $labels) :test #'equal)
+		(setf $labels (delete *linelabel* $labels :count 1 :test #'eq)) t)
+	      (not (eq *linelabel* (cadr $labels))))
+      (setq $labels (cons (car $labels) (cons *linelabel* (cdr $labels))))))
+  *linelabel*)
 
 (defmfun printlabel ()
-  (mtell-open "(~A) " (subseq (print-invert-case linelable) 1)))
+  (mtell-open "(~A) " (subseq (print-invert-case *linelabel*) 1)))
 
 (defmfun mexploden (x)
   (let (*print-radix*
@@ -193,7 +189,7 @@
 		   #+lispworks (pathname-type (compile-file-pathname "foo.lisp"))
 		   #-(or gcl cmu clisp allegro openmcl lispworks) ""))
       (if (member type (list bin-ext "lisp" "lsp")  :test 'equalp)
-	  #-sbcl (load file) #+sbcl (with-compilation-unit nil (load file))
+	  (let ((*read-base* 10.)) #-sbcl (load file) #+sbcl (with-compilation-unit nil (load file)))
 	  ($load file)))))
 
 (defvar autoload 'generic-autoload)
@@ -236,6 +232,7 @@
   (if printp (format t (intl:gettext "loadfile: loading ~A.~%") file))
   (let* ((path (pathname file))
 	 ($load_pathname path)
+	 (*read-base* 10.)
 	 (tem (errset #-sbcl (load (pathname file)) #+sbcl (with-compilation-unit nil (load (pathname file))))))
     (or tem (merror (intl:gettext "loadfile: failed to load ~A") (namestring path)))
     (namestring path)))
@@ -521,7 +518,7 @@
 	     (incharp (char= (getlabcharn (car l1)) inchar)))
 	 (errset
 	  (cond ((and (not nostringp) incharp)
-		 (let ((linelable (car l1))) (mterpri) (printlabel))
+		 (let ((*linelabel* (car l1))) (mterpri) (printlabel))
 		 (if grindp
 		     (mgrind (meval1 (car l1)) nil)
 		     (mapc #'(lambda (x) (write-char x)) (mstring (meval1 (car l1))))) ;gcl doesn't like a
@@ -535,7 +532,7 @@
 			      (if x (mtell (intl:gettext "  GC time = ~A seconds") (cdr l)))
 			      (mterpri))
 			 (not (or inputp (get (car l1) 'nodisp)))))
-		 (mterpri) (displa (list '(mlable) (car l1) (meval1 (car l1)))))
+		 (mterpri) (displa (list '(mlabel) (car l1) (meval1 (car l1)))))
 		(t (go a)))))
        (when (and slowp (cdr l1) (not (continuep)))
 	 (return '$terminated))
@@ -601,14 +598,10 @@
 (defmfun fullstrip1 (x)
   (or (and (numberp x) x)
       (let ((y (get x 'reversealias))) (if y (stripdollar y)))
-      (let ((u (rassoc x aliaslist :test #'eq)))
-	(if u (implode (string*1 (car u)))))
       (stripdollar x)))
 
 (defun string* (x)
   (or (and (numberp x) (exploden x))
-      (let ((u (rassoc x aliaslist :test #'eq)))
-	(if u (string*1 (car u))))
       (string*1 x)))
 
 (defun string*1 (x)
@@ -677,7 +670,7 @@
         ($ibase *read-base* *read-base*) ($obase *print-base* obase)
         ($nopoint *nopoint nopoint)
 	($modulus modulus modulus) ($zunderflow zunderflow zunderflow)
-	($ttyoff #.ttyoff ttyoff) ($writefile_on #.writefilep writefile_on)
+	($ttyoff #.ttyoff ttyoff)
 	($mode_declare $modedeclare mode_declare)))
 
 (mapc #'(lambda (x) (putprop (car x) (cadr x) 'alias))
@@ -838,16 +831,8 @@
 
 ;; File-processing stuff.
 
-;; This prevents single blank lines from appearing at the top of video
-;; terminals.  If at the upper left corner and we want to print a blank
-;; line, leave the cursor there and send the blank line to transcript
-;; files only.
-
 (defmfun mterpri ()
-  (if smart-tty
-      (let ((#.ttyoff t))
-	(terpri))
-      (terpri)))
+   (terpri))
 
 (defmspec $status (form)
   (setq form (cdr form))
